%DECODIFICADOR DE TRAMAS SID.
%function [LARc,Nc,bc,Mc,xmaxc,xmc]=dessid(LARc,Nc,bc,Mc,xmaxc,xmc,flag)
%Entradas:
%LARc:LAR codificados aplicado el sid.
%Nc:término de autocorrelación codificado aplicado el sid.
%bc:ganancia de autocorrelación codificado aplicado el sid.
%Mc:posición RPE codificada aplicado el sid.
%xmaxc:valor máximo RPE codificado aplicado el sid.
%xmc:subsecuencia seleccionada codificada aplicado el sid.
%flag:variable que indica si es una trama sid o no.
%Salidas:
%LARc:LAR codificados.
%Nc:término de autocorrelación codificado.
%bc:ganancia de autocorrelación codificado.
%Mc:posición RPE codificada.
%xmaxc:valor máximo RPE codificado.
%xmc:subsecuencia seleccionada codificada.
function [LARc,Nc,bc,Mc,xmaxc,xmc]=dessid(LARc,Nc,bc,Mc,xmaxc,xmc,flag)
if(flag==1)
	Nc=[40,120,40,120];%se sustituye por esos valores.
	bc=zeros(1,4);%se sustituye por esos valores.
	Mc=round(3*abs(rand(1,4)));%se sustituye por esos valores.
	xmc=round(5*abs(rand(1,52)))+1;%se sustituye por esos valores.
end
